Tutorial
========

This section uses a series of `Jupyter Notebooks <https://jupyter.org/>`_ to explain how PyBLP can be used to solve example problems, compute post-estimation outputs, and simulate problems. Other examples can be found in the :ref:`api:API Documentation`.

.. toctree::
   :maxdepth: 2

   _notebooks/tutorial/logit_nested.ipynb
   _notebooks/tutorial/nevo.ipynb
   _notebooks/tutorial/blp.ipynb
   _notebooks/tutorial/post_estimation.ipynb
   _notebooks/tutorial/simulation.ipynb
